//package com.ibm.rsc;

import java.beans.PropertyVetoException;
import java.io.File;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import com.ibm.as400.access.AS400;
import com.ibm.as400.access.AS400SecurityException;
import com.ibm.as400.access.CommandCall;
import com.ibm.as400.access.ErrorCompletingRequestException;
import com.ibm.as400.access.ObjectDoesNotExistException;
import com.ibm.as400.access.User;

/**
 * The information contained in this document has not been submitted   
 * to any formal tests and is distributed on an 'As is' basis          
 * without any warranty either expressed or implied. The use of this   
 * information or the implementation of any of these techniques is a   
 * customer responsibility and depends on the customer's ability to    
 * evaluate and integrate them into the customer's operation           
 * environment. While each item may have been reviewed by IBM          
 * for accuracy in a specific situation, there is no guarantee that the
 * same or similar results will be obtained elsewhere. Customers       
 * attempting to adapt these techniques to their environments do so    
 * at their own risk.                                                  
 */

public class CreateHomeDirectories {

	/**
	 * This program creates home directories for all of the users on a system.
	 * It makes the user the owner of their own directory.
	 * 
	 * @param args
	 */
	public static void main(String[] args) {
		CreateHomeDirectories app = new CreateHomeDirectories();
		try {
			app.createUserProfileFile();
			app.createHomeDirectories();
			app.deleteUserProfileFile();
		} catch (AS400SecurityException e) {
			System.out.println("The command failed with a security exception.");
			e.printStackTrace();
		} catch (ErrorCompletingRequestException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (InterruptedException e) {
			e.printStackTrace();
		} catch (PropertyVetoException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	
	private void deleteUserProfileFile() throws AS400SecurityException, ErrorCompletingRequestException, IOException, InterruptedException, PropertyVetoException, Exception {
		AS400 as400 = new AS400();
		CommandCall command = new CommandCall(as400);
		if (command.run("DLTF FILE(QGPL/ALLUSERS)"))
			System.out.println("Removed QGPL/ALLUSERS file");
		else {
			System.out.println("Deletion of the QGPL/ALLUSERS file failed.");
			throw new Exception();
		}
		as400.disconnectAllServices();
	}


	private void createHomeDirectories() {
		Connection conn = null;
		Statement stmt = null;
		ResultSet rs = null;
		User user = null;
		String homeDir = null;
		String commandString = null;
		AS400 as400 = new AS400();
		CommandCall command = new CommandCall(as400);
		try {
			Class.forName("com.ibm.db2.jdbc.app.DB2Driver");
			conn = DriverManager.getConnection("jdbc:db2://*LOCAL",null,null);
			stmt = conn.createStatement();
			rs = stmt.executeQuery("Select UPUPRF from QGPL.ALLUSERS");
			while (rs.next()){
				user = new User(as400,rs.getString(1));
				homeDir = user.getHomeDirectory();
//				System.out.println("User " + user.getUserProfileName() + "\t has home directory: " + homeDir);
				if ((new File(homeDir)).mkdirs()){
					commandString = "CHGOWN OBJ('" + homeDir + "') NEWOWN(" + user.getUserProfileName() + ")";
					command.run(commandString);
					System.out.println("Successfully created home directory for user " + user.getUserProfileName() + "\t has home directory:  " + homeDir);
				}
				else
					System.out.println("The home directory for user " + user.getUserProfileName() + "\t already exists, it is:  " + homeDir);
			}
			rs.close();
			stmt.close();
			conn.close();
			as400.disconnectAllServices();
		} catch (ClassNotFoundException e) {
			e.printStackTrace();
		} catch (SQLException e) {
			e.printStackTrace();
		} catch (AS400SecurityException e) {
			e.printStackTrace();
		} catch (ErrorCompletingRequestException e) {
			e.printStackTrace();
		} catch (InterruptedException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (ObjectDoesNotExistException e) {
			e.printStackTrace();
		} catch (PropertyVetoException e) {
			e.printStackTrace();
		}

	}

	
	private void createUserProfileFile() throws AS400SecurityException, ErrorCompletingRequestException, IOException, InterruptedException, PropertyVetoException, Exception {
		AS400 as400 = new AS400();
		CommandCall command = new CommandCall(as400);
		if (command.run("DSPUSRPRF USRPRF(*ALL) TYPE(*BASIC) OUTPUT(*OUTFILE) OUTFILE(QGPL/ALLUSERS) OUTMBR(*FIRST *REPLACE)"))
			System.out.println("Created QGPL/ALLUSERS file");
		else {
			System.out.println("Creation of the QGPL/ALLUSERS file failed.");
			throw new Exception();
		}
		as400.disconnectAllServices();
	}

}
